==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgsBuilder internal
constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("glasrgjxcxpjfnyh")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("vmpkyrtrtxrwsowl")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mhbyeoajwjwdkelw")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("wavnogwvthsmhuvn")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("vxlcsrqdesvxxerq")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs =
        ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs(
            items = items,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgsBuilder internal constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("gjkffibasqyrvxel")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("fthiefetdsrsuoml")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("enguvtdxhcmghxpp")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("jxahmnlieorplaix")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("nomyflddpaqynuyt")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs =
        ResponseHeadersPolicyCorsConfigAccessControlExposeHeadersArgs(
            items = items,
        )
}
